@@ -677,6 +677,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPNODEPORTINVALID = 'InvalidParameterValue.Con
 # 服务端口值非法。
 INVALIDPARAMETERVALUE_CONTAINERGROUPPORTINVALID = 'InvalidParameterValue.ContainergroupPortInvalid'
 
+# 服务端口不能为空。
+INVALIDPARAMETERVALUE_CONTAINERGROUPPORTNULL = 'InvalidParameterValue.ContainergroupPortNull'
+
 # 服务端口不允许重复映射。
 INVALIDPARAMETERVALUE_CONTAINERGROUPPORTSREPEAT = 'InvalidParameterValue.ContainergroupPortsRepeat'
 
